errors

package
v0.8.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 19, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DeployEngineError

type DeployEngineError struct {
	Message string
}

DeployEngineError is an error type returned from a deploy engine instance for validation, build and deployment stages.

func (*DeployEngineError) Error

func (e *DeployEngineError) Error() string

Jump to