params

package
v0.8.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 19, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DefaultContextVars

func DefaultContextVars(config *core.Config) map[string]*bpcore.ScalarValue

DefaultContextVars produces default context variables for the current version of the deploy engine.

Types

type Provider

type Provider interface {
	// GetDefaultParams returns the default set of parameters
	// containing context for the current version of the deploy engine.
	GetDefaultParams() core.BlueprintParams
	// CreateFromRequestConfig creates a set of parameters
	// that merges the provided configuration derived from a request to
	// the deploy engine with the default parameters containing context
	// for the current version of the deploy engine.
	CreateFromRequestConfig(
		reqConfig *types.BlueprintOperationConfig,
	) core.BlueprintParams
}

Provider is an interface for a service that produces `core.BlueprintParams` to be passed into the blueprint loader for validation, change staging, and deployment. This merges deploy engine context with caller-provided configuration.

func NewDefaultProvider

func NewDefaultProvider(defaultContext map[string]*core.ScalarValue) Provider

NewDefaultProvider creates a new instance of the default params provider. This will include the provided default context values in the context variables that can be accessed through the `params.ContextVariable("key")` method in each set of blueprint parameters produced by the provider.

Jump to