utils

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EnsureBlueprintDirContextVar added in v0.2.0

func EnsureBlueprintDirContextVar(config *types.BlueprintOperationConfig, directory string) *types.BlueprintOperationConfig

EnsureBlueprintDirContextVar adds the blueprint directory to the context variables so that the file system resolver can resolve relative child blueprint paths. If the config is nil, a new config is created with just the context variable. Returns the config (possibly newly created) with the blueprint directory set.

func Getenv

func Getenv(key, fallback string) string

Getenv returns the value of the environment variable named by the key, or fallback if the environment variable is not set.

Types

This section is empty.

Jump to