Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DeployEngineError ¶
type DeployEngineError struct {
Message string
}
DeployEngineError is an error type returned from a deploy engine instance for validation, build and deployment stages.
func (*DeployEngineError) Error ¶
func (e *DeployEngineError) Error() string
Click to show internal directories.
Click to hide internal directories.