Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EnsureBlueprintDirContextVar ¶ added in v0.2.0
func EnsureBlueprintDirContextVar(config *types.BlueprintOperationConfig, directory string) *types.BlueprintOperationConfig
EnsureBlueprintDirContextVar adds the blueprint directory to the context variables so that the file system resolver can resolve relative child blueprint paths. If the config is nil, a new config is created with just the context variable. Returns the config (possibly newly created) with the blueprint directory set.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.